@@ -11,8 +11,8 @@ else:
 from .filesplit import Filesplit
 from datetime import datetime
 
-__version__ = '0.3.0'
-URL = 'https://www.d3design.tools'
+__version__ = '0.4.0'
+URL = 'https://d3design.tools'
 
 
 class Client(object):
